| Home | Libraries | People | FAQ | More

# Chapter 18. Octonions

Table of Contents

Overview
Header File
Synopsis
Template Class octonion
Octonion Specializations
Octonion Member Typedefs
Octonion Member Functions
Octonion Non-Member Operators
Octonion Value Operations
Octonion Creation Functions
Octonions Transcendentals
Test Program
Acknowledgements
History
To Do

Copyright © 2006-2021 Nikhar Agrawal, Anton Bikineev, Matthew Borland, Paul A. Bristow, Marco Guazzone, Christopher Kormanyos, Hubert Holin, Bruno Lalande, John Maddock, Evan Miller, Jeremy Murphy, Matthew Pulver, Johan Råde, Gautam Sewani, Benjamin Sobotta, Nicholas Thompson, Thijs van den Berg, Daryle Walker and Xiaogang Zhang

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)